@@ -1,7 +1,10 @@
 from django.core.serializers import serialize
 from django.core.serializers.json import DjangoJSONEncoder
 from django.db.models.query import QuerySet
-from django.utils import simplejson
+try:
+    from django.utils import simplejson as json
+except ImportError:
+    import json
 from django.utils.safestring import mark_safe
 from django.template import Library
 
@@ -11,4 +14,4 @@ register = Library()
 def jsonify(obj):
     if isinstance(obj, QuerySet):
         return mark_safe(serialize('json', obj))
-    return mark_safe(simplejson.dumps(obj, cls=DjangoJSONEncoder))
+    return mark_safe(json.dumps(obj, cls=DjangoJSONEncoder))
